@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.050';
+$Statocles::App::Blog::VERSION = '0.051';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -169,15 +169,21 @@ sub post_files {
     my ( $self ) = @_;
     my @pages;
 
-    my $iter = $self->store->find_files;
+    my @paths;
+    my $iter = $self->store->find_files( include_documents => 1 );
     while ( my $path = $iter->() ) {
+        push @paths, $path;
+    }
+
+    for my $path ( @paths ) {
         # Files must be in folders
         next unless $path =~ m{^/(\d{4})/(\d{2})/(\d{2})/[^/]+/};
 
         # index.markdown is the post itself
         next if $path =~ m{/index[.]markdown$};
+        next if $path =~ m{/index[.]html$};
 
-        if ( $path =~ /[.]markdown$/ ) {
+        if ( $self->store->is_document( $path ) ) {
             my $page_path = $path;
             $page_path =~ s{[.]\w+$}{.html};
 
@@ -191,6 +197,13 @@ sub post_files {
             push @pages, Statocles::Page::Document->new( %args );
         }
         else {
+            # If there's a markdown file, don't keep the html file
+            if ( $path =~ /[.]html$/ ) {
+                my $doc_path = "$path";
+                $doc_path =~ s/[.]html$/.markdown/;
+                next if grep { $_ eq $doc_path } @paths;
+            }
+
             push @pages, Statocles::Page::File->new(
                 path => $path,
                 file_path => $self->store->path->child( $path ),
@@ -475,7 +488,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 DESCRIPTION
 
