@@ -1,6 +1,6 @@
 package Statocles::App::Perldoc;
 # ABSTRACT: Render documentation for Perl modules
-$Statocles::App::Perldoc::VERSION = '0.050';
+$Statocles::App::Perldoc::VERSION = '0.051';
 use Statocles::Base 'Class';
 use Statocles::Page::Plain;
 use Scalar::Util qw( blessed );
@@ -103,17 +103,8 @@ sub pages {
 
             # Rewrite links for modules that we will be serving locally
             if ( grep { $href =~ /^$pod_base$_/ } @{ $self->modules } ) {
-                my $new_href;
-                if ( $href eq $self->index_module ) {
-                    $new_href = 'index.html';
-                }
-                else {
-                    $new_href = $href;
-                    $new_href =~ s/$pod_base//;
-                    $new_href = join '/', split /::/, $new_href;
-                    $new_href .= '.html';
-                }
-                $node->attr( href => $self->url( $new_href ) );
+                my ( $module ) = $href =~ /^$pod_base(.+)$/;
+                $node->attr( href => $self->url( $self->_module_href( $module ) ) );
             }
             # Add rel="external" for remaining external links
             elsif ( $href =~ m{(?:[^:]+:)?//} ) {
@@ -281,7 +272,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 DESCRIPTION
 
