@@ -1,6 +1,6 @@
 package Statocles::App::Static;
 # ABSTRACT: Manage static files like CSS, JS, images, and other untemplated content
-$Statocles::App::Static::VERSION = '0.050';
+$Statocles::App::Static::VERSION = '0.051';
 use Statocles::Base 'Class';
 use Statocles::Page::File;
 with 'Statocles::App';
@@ -18,7 +18,7 @@ sub pages {
     my ( $self ) = @_;
 
     my @pages;
-    my $iter = $self->store->find_files;
+    my $iter = $self->store->find_files( include_documents => 1 );
     FILE: while ( my $path = $iter->() ) {
         # Check for hidden files and folders
         next if $path->basename =~ /^[.]/;
@@ -49,7 +49,7 @@ Statocles::App::Static - Manage static files like CSS, JS, images, and other unt
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 DESCRIPTION
 
