@@ -1,6 +1,6 @@
 package Statocles::Deploy::File;
 # ABSTRACT: Deploy a site to a folder on the filesystem
-$Statocles::Deploy::File::VERSION = '0.050';
+$Statocles::Deploy::File::VERSION = '0.051';
 use Statocles::Base 'Class';
 with 'Statocles::Deploy';
 
@@ -17,7 +17,7 @@ sub deploy {
     my ( $self, $from_store, $message ) = @_;
 
     my @files;
-    my $iter = $from_store->find_files;
+    my $iter = $from_store->find_files( include_documents => 1 );
     while ( my $path = $iter->() ) {
         # Git versions before 1.7.4.1 require a relative path to 'git add'
         push @files, $path->relative( "/" )->stringify;
@@ -45,7 +45,7 @@ Statocles::Deploy::File - Deploy a site to a folder on the filesystem
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 DESCRIPTION
 
