@@ -1,6 +1,6 @@
 package Statocles::Plugin::LinkCheck;
 # ABSTRACT: Check links and images for validity during build
-$Statocles::Plugin::LinkCheck::VERSION = '0.050';
+$Statocles::Plugin::LinkCheck::VERSION = '0.051';
 use Statocles::Base 'Class';
 use Mojo::DOM;
 use Mojo::Util qw( url_escape url_unescape );
@@ -28,7 +28,7 @@ sub check_pages {
                     my $url = $el->attr( $attr );
                     $url =~ s{#.*$}{};
                     next unless $url;
-                    next if $url =~ m{^(?:https?|mailto|javascript):/};
+                    next if $url =~ m{^(?:[a-z][a-z0-9+.-]*):}i;
                     next if $url =~ m{^//};
                     if ( $url !~ m{^/} ) {
                         $url = $page->path->parent->child( $url );
@@ -63,7 +63,7 @@ Statocles::Plugin::LinkCheck - Check links and images for validity during build
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 SYNOPSIS
 
