@@ -1,6 +1,6 @@
 package Statocles::Store::File;
 # ABSTRACT: A store made up of plain files
-$Statocles::Store::File::VERSION = '0.050';
+$Statocles::Store::File::VERSION = '0.051';
 use Statocles::Base 'Class';
 with 'Statocles::Store';
 use Scalar::Util qw( weaken blessed );
@@ -25,6 +25,20 @@ has path => (
 );
 
 
+has document_extensions => (
+    is => 'ro',
+    isa => ArrayRef[Str],
+    default => sub { [qw( markdown md )] },
+    coerce => sub {
+        my ( $ext ) = @_;
+        if ( !ref $ext ) {
+            return [ split /[, ]/, $ext ];
+        }
+        return $ext;
+    },
+);
+
+
 has documents => (
     is => 'rw',
     isa => ArrayRef[InstanceOf['Statocles::Document']],
@@ -70,10 +84,9 @@ sub read_documents {
     while ( my $path = $iter->() ) {
         next unless $path->is_file;
         next unless $self->_is_owned_path( $path );
-        if ( $path =~ /[.]markdown$/ ) {
-            my $rel_path = rootdir->child( $path->relative( $root_path ) );
-            push @docs, $self->read_document( $rel_path );
-        }
+        next unless $self->is_document( $path );
+        my $rel_path = rootdir->child( $path->relative( $root_path ) );
+        push @docs, $self->read_document( $rel_path );
     }
     return \@docs;
 }
@@ -196,6 +209,13 @@ sub _freeze_document {
 }
 
 
+sub is_document {
+    my ( $self, $path ) = @_;
+    my $match = join "|", @{ $self->document_extensions };
+    return $path =~ /[.](?:$match)$/;
+}
+
+
 sub read_file {
     my ( $self, $path ) = @_;
     site->log->debug( "Read file: " . $path );
@@ -210,12 +230,16 @@ sub has_file {
 
 
 sub find_files {
-    my ( $self ) = @_;
+    my ( $self, %opt ) = @_;
     my $iter = $self->path->iterator({ recurse => 1 });
     return sub {
-        my $path = $iter->();
-        return unless $path; # iterator exhausted
-        $path = $iter->() while $path && ( $path->is_dir || !$self->_is_owned_path( $path ) );
+        my $path;
+        while ( $path = $iter->() ) {
+            next if $path->is_dir;
+            next if !$self->_is_owned_path( $path );
+            next if !$opt{include_documents} && $self->is_document( $path );
+            last;
+        }
         return unless $path; # iterator exhausted
         return $path->relative( $self->path )->absolute( '/' );
     };
@@ -258,7 +282,7 @@ Statocles::Store::File - A store made up of plain files
 
 =head1 VERSION
 
-version 0.050
+version 0.051
 
 =head1 DESCRIPTION
 
@@ -283,6 +307,11 @@ on the bottom, like so:
 
 The path to the directory containing the L<documents|Statocles::Document>.
 
+=head2 document_extensions
+
+An array of file extensions that should be considered documents. Defaults to
+"markdown" and "md".
+
 =head2 documents
 
 All the L<documents|Statocles::Document> currently read by this store.
@@ -315,6 +344,10 @@ the newly-updated document.
 
 The document is written in Frontmatter format.
 
+=head2 is_document( $path )
+
+Returns true if the path looks like a document path (matches the L</document_extensions>).
+
 =head2 read_file( $path )
 
 Read the file from the given C<path>.
@@ -326,11 +359,16 @@ Returns true if a file exists with the given C<path>.
 NOTE: This should not be used to check for directories, as not all stores have
 directories.
 
-=head2 find_files()
+=head2 find_files( %opt )
 
 Returns an iterator that, when called, produces a single path suitable to be passed
 to L<read_file>.
 
+Available options are:
+
+    include_documents      - If true, will include files that look like documents.
+                             Defaults to false.
+
 =head2 open_file( $path )
 
 Open the file with the given path. Returns a filehandle.
